/*
 * Copyright (c) 2021.
 * Microsoft Corporation. All rights reserved.
 */

function initializeWac() {
    var params = JSON.parse(Previewer.getWacParams())
    var script = document.createElement('script')
    script.type = 'text/javascript'
    script.src = params.bootstrapperUrl
    script.onload = function () {
        if (params.appName === 'PowerPoint') {
            // PowerPoint only supports JsApiV1 now
            bootJsApi(params)
        } else {
            bootJsApiV2(params)
        }
    }
    document.head.appendChild(script)
}

// JsApiV1 sample https://microsoft.sharepoint.com/:w:/t/powerpoint/ERO3oJYetRVDkCdBXLWtPkwBd0Tw1t3zgzY-wpBefbvV-g?e=SEYsmz
function bootJsApi(params) {
    var initParams = {
        Container: document.getElementById("WopiDocWACContainer"),
        ApplicationUrl: params.applicationUrl,
        BootstrapperUrl: params.bootstrapperUrl,
        SessionInformation: {
            HostName: 'SharePoint Online',
            HostSessionId: params.sessionId,
            UserId: params.userId
        },
        WopiInfo: {
            WopiSrc: params.wopiSrc,
            AccessToken: params.token,
            AccessTokenExpiry: new Date(parseInt(params.tokenExpiry))
        },
        WopiPrecheckInfo: {
            FileGetUrl: params.fileGetUrl,
            FileName: params.fileName,
            FileSize: params.fileSize,
        },
        FnOnInitializeSuccess: function (app, appInitDiagnostics) {},
        FnOnInitializeFailure: function (error) {}
    }
    Microsoft.Office[params.appName].Application.InitializeWopiPending(initParams)
}

// JsApi2 sample https://office.visualstudio.com/OC/_wiki/wikis/OC.wiki/18270/Sample-usage
function bootJsApiV2(params) {
    var applicationInitParams = {
        host: {
            storageHostName: 'SharePoint Online',
            uiHostName: 'Outlook for Android',
            requireExplicitUnload: false,
            capabilities: {
                accessibilityLoop: true,
                decryptedContentDownload: true,
                isFeatureEnabledCallback: function () {
                    return false
                }
            }
        },
        user: {
            id: params.userId
        },
        bootstrapperUrl: params.bootstrapperUrl,
        ui: {
            language: navigator.language,
            uiEmbed: true,
            hideHeader: true,
            highContrast: false,
            controls: [
                { id: 'openInApp', visibility: 0 },
                { id: 'docChat', visibility: 0 },
                { id: 'share', visibility: 0 },
                { id: 'conversation', visibility: 0 },
                { id: 'ellipsisOpenInApp', visibility: 0 },
                { id: 'ellipsisOpenInBrowser', visibility: 0 },
                { id: 'ellipsisDownload', visibility: 0 },
                { id: 'close', visibility: 0 }
            ]
        },
        viewMode: {
            hideToolbar: true,
            disableFocusOnBoot: false,
            forceAccessibilityMode: false
        }
    }
    var application = Microsoft.Office[params.appName].createApplication(applicationInitParams)

    var sessionInitParams = {
        hostSessionId: params.sessionId
    }
    var session = application.createSession(sessionInitParams)

    var sessionBootParams = {
        appUrl: params.applicationUrl,
        file: {
            name: params.fileName,
            getUrl: params.fileGetUrl,
            size: params.fileSize
        },
        container: document.getElementById("WopiDocWACContainer"),
        wopi: {
            source: params.wopiSrc,
            accessToken: params.token,
            expiry: params.tokenExpiry
        }
    }
    session.boot(sessionBootParams)
}

window.onload = initializeWac